# 📰 Treestamps News

## v0.2.0

- Features

  - Support ignore globs

## v0.1.3

- Fixes

  - Protect final dump yaml from child cleanup task.

## v0.1.2

- Features

  - colored output.

- Fixes

  - Trap more errors when reading timestamps

## v0.1.1

- Fixes

  - Fix strings submitted to factory instead of paths

## v0.1.0

_First Release_

- Picopt's new timestamper abstracted to a library
